@@ -182,7 +182,7 @@ QColor Helper::buttonBackgroundColor(const QPalette &palette, bool mouseOver, bo
             // Hovered button for normal mode is bg_color
             return mix(buttonBackground, background, opacity);
         }
-    } else if(mouseOver) {
+    } else if (mouseOver) {
         if (darkMode) {
             // Hovered button for dark mode is darken(bg_color, 0.01)
             return darken(background, 0.01);
@@ -575,10 +575,10 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
         painter->setBrush(Qt::NoBrush);
 
     painter->setRenderHint(QPainter::Antialiasing, false);
-    QRect frameRect(rect);
+    QRectF frameRect(rect);
     if (outline.isValid()) {
         painter->setPen(outline);
-        frameRect.adjust(0, 0, -1, -1);
+        frameRect.adjust(0.5, 0.5, -0.5, -0.5);
     } else
         painter->setPen(Qt::NoPen);
 
